@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.42 2004/02/04 00:00:12 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.44 2004/02/27 15:46:03 richb Exp $
  *
  *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -58,7 +58,7 @@ localize_number(char *dest, const char *src)
     	while (srcp >= src) {
             *dstp++ = *srcp--;
             n++;
-            if (n == 3 && srcp >= src) {
+            if (n == 3 && srcp >= src && *srcp != '-') {
 	        for (i = tsep_len - 1; i >= 0; i--)
 		    *dstp++ = v->tsep[i];
 		n = 0;
